/*
** ###################################################################
**     Build:               b150605
**
**     Abstract:
**         Enumeration value mapping header.
**
**     Copyright (c) 2015 Freescale Semiconductor, Inc.
**     All rights reserved.
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of Freescale Semiconductor, Inc. nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**     http:                 www.freescale.com
**     mail:                 support@freescale.com
**
**     Revisions:
**
** ###################################################################
*/

#if !defined(__FSL_EDMA_REQUEST_H__)
#define __FSL_EDMA_REQUEST_H__

/*!
 * @addtogroup edma_request
 * @{
 */

/*******************************************************************************
 * Definitions
 ******************************************************************************/

/*!
 * @brief Structure for the DMA hardware request
 *
 * Defines the structure for the DMA hardware request collections. The user can configure the
 * hardware request into DMAMUX to trigger the DMA transfer accordingly. The index
 * of the hardware request varies according  to the to SoC.
 */
typedef enum _dma_request_source {
#if defined(CPU_MK02FN128VFM10) || defined(CPU_MK02FN64VFM10) || defined(CPU_MK02FN128VLF10) || defined(CPU_MK02FN64VLF10) || \
    defined(CPU_MK02FN128VLH10) || defined(CPU_MK02FN64VLH10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0Reserved6 = 6|0x100U, /*!< Reserved6 */
    kDmaRequestMux0Reserved7 = 7|0x100U, /*!< Reserved7 */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0Reserved16 = 16|0x100U, /*!< Reserved16 */
    kDmaRequestMux0Reserved17 = 17|0x100U, /*!< Reserved17 */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0Reserved19 = 19|0x100U, /*!< Reserved19 */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0Reserved26 = 26|0x100U, /*!< Reserved26 */
    kDmaRequestMux0Reserved27 = 27|0x100U, /*!< Reserved27 */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0Reserved32 = 32|0x100U, /*!< Reserved32 */
    kDmaRequestMux0Reserved33 = 33|0x100U, /*!< Reserved33 */
    kDmaRequestMux0Reserved34 = 34|0x100U, /*!< Reserved34 */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0Reserved41 = 41|0x100U, /*!< Reserved41 */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0Reserved47 = 47|0x100U, /*!< Reserved47 */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0Reserved58 = 58|0x100U, /*!< Reserved58 */
    kDmaRequestMux0Reserved59 = 59|0x100U, /*!< Reserved59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK10DN512VLK10) || defined(CPU_MK20DN512VLK10) || defined(CPU_MK20DX256VLK10) || defined(CPU_MK30DN512VLK10) || \
    defined(CPU_MK40DN512VLK10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 Output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK10DN512VLL10) || defined(CPU_MK20DN512VLL10) || defined(CPU_MK20DX256VLL10) || defined(CPU_MK30DN512VLL10) || \
    defined(CPU_MK40DN512VLL10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0UART4Rx = 10|0x100U, /*!< UART4 receive complete */
    kDmaRequestMux0UART4Tx = 11|0x100U, /*!< UART4 transmit complete */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0SPI2Rx = 20|0x100U, /*!< SPI2 receive complete */
    kDmaRequestMux0SPI2Tx = 21|0x100U, /*!< SPI2 transmit complete */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 Output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK10DX128VLQ10) || defined(CPU_MK10DX256VLQ10) || defined(CPU_MK10DN512VLQ10) || defined(CPU_MK10DN512VMC10) || \
    defined(CPU_MK10DX128VMD10) || defined(CPU_MK10DX256VMD10) || defined(CPU_MK10DN512VMD10) || defined(CPU_MK20DX128VLQ10) || \
    defined(CPU_MK20DX256VLQ10) || defined(CPU_MK20DN512VLQ10) || defined(CPU_MK20DX256VMC10) || defined(CPU_MK20DN512VMC10) || \
    defined(CPU_MK20DX128VMD10) || defined(CPU_MK20DX256VMD10) || defined(CPU_MK20DN512VMD10) || defined(CPU_MK30DX128VLQ10) || \
    defined(CPU_MK30DX256VLQ10) || defined(CPU_MK30DN512VLQ10) || defined(CPU_MK30DN512VMC10) || defined(CPU_MK30DX128VMD10) || \
    defined(CPU_MK30DX256VMD10) || defined(CPU_MK30DN512VMD10) || defined(CPU_MK40DX128VLQ10) || defined(CPU_MK40DX256VLQ10) || \
    defined(CPU_MK40DN512VLQ10) || defined(CPU_MK40DN512VMC10) || defined(CPU_MK40DX128VMD10) || defined(CPU_MK40DX256VMD10) || \
    defined(CPU_MK40DN512VMD10) || defined(CPU_MK50DN512CLQ10) || defined(CPU_MK50DX256CMC10) || defined(CPU_MK50DN512CMC10) || \
    defined(CPU_MK50DN512CMD10) || defined(CPU_MK50DX256CMD10) || defined(CPU_MK51DN256CLQ10) || defined(CPU_MK51DN512CLQ10) || \
    defined(CPU_MK51DX256CMC10) || defined(CPU_MK51DN512CMC10) || defined(CPU_MK51DN256CMD10) || defined(CPU_MK51DN512CMD10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0UART4Rx = 10|0x100U, /*!< UART4 receive complete */
    kDmaRequestMux0UART4Tx = 11|0x100U, /*!< UART4 transmit complete */
    kDmaRequestMux0UART5Rx = 12|0x100U, /*!< UART5 receive complete */
    kDmaRequestMux0UART5Tx = 13|0x100U, /*!< UART5 transmit complete */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0SPI2Rx = 20|0x100U, /*!< SPI2 receive complete */
    kDmaRequestMux0SPI2Tx = 21|0x100U, /*!< SPI2 transmit complete */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 Output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK11DX128AVLK5WS) || defined(CPU_MK11DX256AVLK5WS) || defined(CPU_MK11DN512AVLK5WS) || defined(CPU_MK11DX128AVLK5) || \
    defined(CPU_MK11DX256AVLK5) || defined(CPU_MK11DN512AVLK5) || defined(CPU_MK11DX128VLK5WS) || defined(CPU_MK11DX256VLK5WS) || \
    defined(CPU_MK11DN512VLK5WS) || defined(CPU_MK11DX128VLK5) || defined(CPU_MK11DX256VLK5) || defined(CPU_MK11DN512VLK5) || \
    defined(CPU_MK21DX128AVLK5WS) || defined(CPU_MK21DX256AVLK5WS) || defined(CPU_MK21DN512AVLK5WS) || defined(CPU_MK21DX128AVLK5) || \
    defined(CPU_MK21DX256AVLK5) || defined(CPU_MK21DN512AVLK5) || defined(CPU_MK21DX128VLK5WS) || defined(CPU_MK21DX256VLK5WS) || \
    defined(CPU_MK21DN512VLK5WS) || defined(CPU_MK21DX128VLK5) || defined(CPU_MK21DX256VLK5) || defined(CPU_MK21DN512VLK5)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0Reserved41 = 41|0x100U, /*!< Reserved41 */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0Reserved45 = 45|0x100U, /*!< Reserved45 */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK11DX128AVMC5WS) || defined(CPU_MK11DX256AVMC5WS) || defined(CPU_MK11DN512AVMC5WS) || defined(CPU_MK11DX128AVMC5) || \
    defined(CPU_MK11DX256AVMC5) || defined(CPU_MK11DN512AVMC5) || defined(CPU_MK11DX128VMC5WS) || defined(CPU_MK11DX256VMC5WS) || \
    defined(CPU_MK11DN512VMC5WS) || defined(CPU_MK11DX128VMC5) || defined(CPU_MK11DX256VMC5) || defined(CPU_MK11DN512VMC5) || \
    defined(CPU_MK12DX128VLK5) || defined(CPU_MK12DX256VLK5) || defined(CPU_MK12DN512VLK5) || defined(CPU_MK12DX128VMC5) || \
    defined(CPU_MK12DX256VMC5) || defined(CPU_MK12DN512VMC5) || defined(CPU_MK21DX128AVMC5WS) || defined(CPU_MK21DX256AVMC5WS) || \
    defined(CPU_MK21DN512AVMC5WS) || defined(CPU_MK21DX128AVMC5) || defined(CPU_MK21DX256AVMC5) || defined(CPU_MK21DN512AVMC5) || \
    defined(CPU_MK21DX128VMC5WS) || defined(CPU_MK21DX256VMC5WS) || defined(CPU_MK21DN512VMC5WS) || defined(CPU_MK21DX128VMC5) || \
    defined(CPU_MK21DX256VMC5) || defined(CPU_MK21DN512VMC5) || defined(CPU_MK22DX128VLK5) || defined(CPU_MK22DX256VLK5) || \
    defined(CPU_MK22DN512VLK5) || defined(CPU_MK22DX128VMC5) || defined(CPU_MK22DX256VMC5) || defined(CPU_MK22DN512VMC5)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0Reserved41 = 41|0x100U, /*!< Reserved41 */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK12DX128VLH5) || defined(CPU_MK12DX256VLH5) || defined(CPU_MK12DN512VLH5) || defined(CPU_MK22DX128VLH5) || \
    defined(CPU_MK22DX256VLH5) || defined(CPU_MK22DN512VLH5)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0Reserved18 = 18|0x100U, /*!< Reserved18 */
    kDmaRequestMux0Reserved19 = 19|0x100U, /*!< Reserved19 */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0Reserved41 = 41|0x100U, /*!< Reserved41 */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK12DX128VLF5) || defined(CPU_MK12DX256VLF5) || defined(CPU_MK22DX128VLF5) || defined(CPU_MK22DX256VLF5)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0Reserved18 = 18|0x100U, /*!< Reserved18 */
    kDmaRequestMux0Reserved19 = 19|0x100U, /*!< Reserved19 */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved34 = 34|0x100U, /*!< Reserved34 */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0Reserved41 = 41|0x100U, /*!< Reserved41 */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0Reserved45 = 45|0x100U, /*!< Reserved45 */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK21FX512AVLQ12WS) || defined(CPU_MK21FN1M0AVLQ12WS) || defined(CPU_MK21FX512AVLQ12) || defined(CPU_MK21FN1M0AVLQ12) || \
    defined(CPU_MK21FX512AVMC12WS) || defined(CPU_MK21FN1M0AVMC12WS) || defined(CPU_MK21FX512AVMC12) || defined(CPU_MK21FN1M0AVMC12) || \
    defined(CPU_MK21FX512AVMD12WS) || defined(CPU_MK21FN1M0AVMD12WS) || defined(CPU_MK21FX512AVMD12) || defined(CPU_MK21FN1M0AVMD12) || \
    defined(CPU_MK22FX512AVLQ12) || defined(CPU_MK22FN1M0AVLQ12) || defined(CPU_MK22FX512AVMC12) || defined(CPU_MK22FN1M0AVMC12) || \
    defined(CPU_MK22FX512AVMD12) || defined(CPU_MK22FN1M0AVMD12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 Receive. */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 Transmit. */
    kDmaRequestMux0UART4 = 10|0x100U, /*!< UART4 Transmit or Receive. */
    kDmaRequestMux0UART5 = 11|0x100U, /*!< UART5 Transmit or Receive. */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0SPI2 = 17|0x100U, /*!< SPI2 Transmit or Receive. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1. */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK22FN128VDC10) || defined(CPU_MK22FN128VLH10) || defined(CPU_MK22FN128VLL10) || defined(CPU_MK22FN128VMP10) || \
    defined(CPU_MK22FN256CAH12) || defined(CPU_MK22FN128CAH12) || defined(CPU_MK22FN256VDC12) || defined(CPU_MK22FN256VLH12) || \
    defined(CPU_MK22FN256VLL12) || defined(CPU_MK22FN256VMP12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0Reserved17 = 17|0x100U, /*!< Reserved17 */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0Reserved32 = 32|0x100U, /*!< Reserved32 */
    kDmaRequestMux0Reserved33 = 33|0x100U, /*!< Reserved33 */
    kDmaRequestMux0Reserved34 = 34|0x100U, /*!< Reserved34 */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0Reserved47 = 47|0x100U, /*!< Reserved47 */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0LPUART0Rx = 58|0x100U, /*!< LPUART0 Receive. */
    kDmaRequestMux0LPUART0Tx = 59|0x100U, /*!< LPUART0 Transmit. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK22FX512AVLH12) || defined(CPU_MK22FN1M0AVLH12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0Reserved16 = 16|0x100U, /*!< Reserved16 */
    kDmaRequestMux0Reserved17 = 17|0x100U, /*!< Reserved17 */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK22FX512AVLK12) || defined(CPU_MK22FN1M0AVLK12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 Receive. */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 Transmit. */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0Reserved17 = 17|0x100U, /*!< Reserved17 */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK22FX512AVLL12) || defined(CPU_MK22FN1M0AVLL12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 Receive. */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 Transmit. */
    kDmaRequestMux0UART4 = 10|0x100U, /*!< UART4 Transmit or Receive. */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0SPI2 = 17|0x100U, /*!< SPI2 Transmit or Receive. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK22FN512CAP12) || defined(CPU_MK22FN512VDC12) || defined(CPU_MK22FN512VLH12) || defined(CPU_MK22FN512VLL12) || \
    defined(CPU_MK22FN512VMP12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0Reserved17 = 17|0x100U, /*!< Reserved17 */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1. */
    kDmaRequestMux0Reserved47 = 47|0x100U, /*!< Reserved47 */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0LPUART0Rx = 58|0x100U, /*!< LPUART0 Receive. */
    kDmaRequestMux0LPUART0Tx = 59|0x100U, /*!< LPUART0 Transmit. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK24FN1M0VDC12) || defined(CPU_MK24FN1M0VLL12) || defined(CPU_MK24FN1M0VLQ12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 Receive. */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 Transmit. */
    kDmaRequestMux0UART4 = 10|0x100U, /*!< UART4 Transmit or Receive. */
    kDmaRequestMux0UART5 = 11|0x100U, /*!< UART5 Transmit or Receive. */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0SPI2 = 17|0x100U, /*!< SPI2 Transmit or Receive. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1. */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK24FN256VDC12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 Receive. */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 Transmit. */
    kDmaRequestMux0UART4 = 10|0x100U, /*!< UART4 Transmit or Receive. */
    kDmaRequestMux0UART5 = 11|0x100U, /*!< UART5 Transmit or Receive. */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0SPI2 = 17|0x100U, /*!< SPI2 Transmit or Receive. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK26FN2M0CAC18) || defined(CPU_MK26FN2M0VLQ18) || defined(CPU_MK26FN2M0VMD18) || defined(CPU_MK26FN2M0VMI18)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0TSI0 = 1|0x100U, /*!< TSI0. */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 Receive. */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 Transmit. */
    kDmaRequestMux0UART4 = 10|0x100U, /*!< UART4 Transmit or Receive. */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1Rx = 16|0x100U, /*!< SPI1 Receive. */
    kDmaRequestMux0SPI1Tx = 17|0x100U, /*!< SPI1 Transmit. */
    kDmaRequestMux0I2C0I2C3 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C3 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1TPM1Channel0 = 28|0x100U, /*!< FTM1 C0V and TPM1 C0V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V and TPM1 C0V. */
    kDmaRequestMux0TPM1Channel0 = 28|0x100U, /*!< FTM1 C0V and TPM1 C0V. */
    kDmaRequestMux0FTM1TPM1Channel1 = 29|0x100U, /*!< FTM1 C1V and TPM1 C1V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V and TPM1 C1V. */
    kDmaRequestMux0TPM1Channel1 = 29|0x100U, /*!< FTM1 C1V and TPM1 C1V. */
    kDmaRequestMux0FTM2TPM2Channel0 = 30|0x100U, /*!< FTM2 C0V and TPM2 C0V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V and TPM2 C0V. */
    kDmaRequestMux0TPM2Channel0 = 30|0x100U, /*!< FTM2 C0V and TPM2 C0V. */
    kDmaRequestMux0FTM2TPM2Channel1 = 31|0x100U, /*!< FTM2 C1V and TPM2 C1V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V and TPM2 C1V. */
    kDmaRequestMux0TPM2Channel1 = 31|0x100U, /*!< FTM2 C1V and TPM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6SPI2Rx = 38|0x100U, /*!< FTM3 C6V and SPI2 Receive. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V and SPI2 Receive. */
    kDmaRequestMux0SPI2Rx = 38|0x100U, /*!< FTM3 C6V and SPI2 Receive. */
    kDmaRequestMux0FTM3Channel7SPI2Tx = 39|0x100U, /*!< FTM3 C7V and SPI2 Transmit. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V and SPI2 Transmit. */
    kDmaRequestMux0SPI2Tx = 39|0x100U, /*!< FTM3 C7V and SPI2 Transmit. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2CMP3 = 44|0x100U, /*!< CMP2 and CMP3. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 and CMP3. */
    kDmaRequestMux0CMP3 = 44|0x100U, /*!< CMP2 and CMP3. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1. */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0TPM1Overflow = 55|0x100U, /*!< TPM1. */
    kDmaRequestMux0TPM2Overflow = 56|0x100U, /*!< TPM2. */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0LPUART0Rx = 58|0x100U, /*!< LPUART0 Receive. */
    kDmaRequestMux0LPUART0Tx = 59|0x100U, /*!< LPUART0 Transmit. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK50DX256CLL10) || defined(CPU_MK50DN512CLL10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0UART4Rx = 10|0x100U, /*!< UART4 receive complete */
    kDmaRequestMux0UART4Tx = 11|0x100U, /*!< UART4 transmit complete */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0SPI2Rx = 20|0x100U, /*!< SPI2 receive complete */
    kDmaRequestMux0SPI2Tx = 21|0x100U, /*!< SPI2 transmit complete */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 Output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK50DX256CLK10) || defined(CPU_MK51DX256CLK10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 Output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0Reserved53 = 53|0x100U, /*!< Reserved53 */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK51DX256CLL10) || defined(CPU_MK51DN512CLL10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0SPI2Rx = 20|0x100U, /*!< SPI2 receive complete */
    kDmaRequestMux0SPI2Tx = 21|0x100U, /*!< SPI2 transmit complete */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 Output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK52DN512CLQ10) || defined(CPU_MK52DN512CMD10) || defined(CPU_MK53DN512CLQ10) || defined(CPU_MK53DX256CLQ10) || \
    defined(CPU_MK53DN512CMD10) || defined(CPU_MK53DX256CMD10) || defined(CPU_MK60DN256VLQ10) || defined(CPU_MK60DX256VLQ10) || \
    defined(CPU_MK60DN512VLQ10) || defined(CPU_MK60DN256VMC10) || defined(CPU_MK60DX256VMC10) || defined(CPU_MK60DN512VMC10) || \
    defined(CPU_MK60DN256VMD10) || defined(CPU_MK60DX256VMD10) || defined(CPU_MK60DN512VMD10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0UART4Rx = 10|0x100U, /*!< UART4 receive complete */
    kDmaRequestMux0UART4Tx = 11|0x100U, /*!< UART4 transmit complete */
    kDmaRequestMux0UART5Rx = 12|0x100U, /*!< UART5 receive complete */
    kDmaRequestMux0UART5Tx = 13|0x100U, /*!< UART5 transmit complete */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0SPI2Rx = 20|0x100U, /*!< SPI2 receive complete */
    kDmaRequestMux0SPI2Tx = 21|0x100U, /*!< SPI2 transmit complete */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0IEEE1588Timer0 = 36|0x100U, /*!< Ethernet IEEE 1588 timer 0 */
    kDmaRequestMux0IEEE1588Timer1 = 37|0x100U, /*!< Ethernet IEEE 1588 timer 1 */
    kDmaRequestMux0IEEE1588Timer2 = 38|0x100U, /*!< Ethernet IEEE 1588 timer 2 */
    kDmaRequestMux0IEEE1588Timer3 = 39|0x100U, /*!< Ethernet IEEE 1588 timer 3 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 Output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK60DN256VLL10) || defined(CPU_MK60DX256VLL10) || defined(CPU_MK60DN512VLL10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 receive complete */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 transmit complete */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 receive complete */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 transmit complete */
    kDmaRequestMux0UART4Rx = 10|0x100U, /*!< UART4 receive complete */
    kDmaRequestMux0UART4Tx = 11|0x100U, /*!< UART4 transmit complete */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 receive complete */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 transmit complete */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 receive complete */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 transmit complete */
    kDmaRequestMux0SPI2Rx = 20|0x100U, /*!< SPI2 receive complete */
    kDmaRequestMux0SPI2Tx = 21|0x100U, /*!< SPI2 transmit complete */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1 transmission complete */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0IEEE1588Timer0 = 36|0x100U, /*!< Ethernet IEEE 1588 timer 0 */
    kDmaRequestMux0IEEE1588Timer1 = 37|0x100U, /*!< Ethernet IEEE 1588 timer 1 */
    kDmaRequestMux0IEEE1588Timer2 = 38|0x100U, /*!< Ethernet IEEE 1588 timer 2 */
    kDmaRequestMux0IEEE1588Timer3 = 39|0x100U, /*!< Ethernet IEEE 1588 timer 3 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 Output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT end of modulation cycle event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MK63FN1M0VLQ12WS) || defined(CPU_MK63FN1M0VLQ12) || defined(CPU_MK63FN1M0VMD12WS) || defined(CPU_MK63FN1M0VMD12) || \
    defined(CPU_MK64FX512VDC12) || defined(CPU_MK64FN1M0VDC12) || defined(CPU_MK64FX512VLQ12) || defined(CPU_MK64FN1M0VLQ12) || \
    defined(CPU_MK64FX512VMD12) || defined(CPU_MK64FN1M0VMD12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 Receive. */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 Transmit. */
    kDmaRequestMux0UART4 = 10|0x100U, /*!< UART4 Transmit or Receive. */
    kDmaRequestMux0UART5 = 11|0x100U, /*!< UART5 Transmit or Receive. */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0SPI2 = 17|0x100U, /*!< SPI2 Transmit or Receive. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1. */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0IEEE1588Timer0 = 54|0x100U, /*!< ENET IEEE 1588 timer 0. */
    kDmaRequestMux0IEEE1588Timer1 = 55|0x100U, /*!< ENET IEEE 1588 timer 1. */
    kDmaRequestMux0IEEE1588Timer2 = 56|0x100U, /*!< ENET IEEE 1588 timer 2. */
    kDmaRequestMux0IEEE1588Timer3 = 57|0x100U, /*!< ENET IEEE 1588 timer 3. */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK64FX512VLL12) || defined(CPU_MK64FN1M0VLL12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 Receive. */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 Transmit. */
    kDmaRequestMux0UART4 = 10|0x100U, /*!< UART4 Transmit or Receive. */
    kDmaRequestMux0UART5 = 11|0x100U, /*!< UART5 Transmit or Receive. */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0SPI2 = 17|0x100U, /*!< SPI2 Transmit or Receive. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0IEEE1588Timer0 = 54|0x100U, /*!< ENET IEEE 1588 timer 0. */
    kDmaRequestMux0IEEE1588Timer1 = 55|0x100U, /*!< ENET IEEE 1588 timer 1. */
    kDmaRequestMux0IEEE1588Timer2 = 56|0x100U, /*!< ENET IEEE 1588 timer 2. */
    kDmaRequestMux0IEEE1588Timer3 = 57|0x100U, /*!< ENET IEEE 1588 timer 3. */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK65FN2M0CAC18) || defined(CPU_MK65FX1M0CAC18) || defined(CPU_MK65FN2M0CAC18WS) || defined(CPU_MK65FX1M0CAC18WS) || \
    defined(CPU_MK65FN2M0VMI18) || defined(CPU_MK65FX1M0VMI18) || defined(CPU_MK65FN2M0VMI18WS) || defined(CPU_MK65FX1M0VMI18WS) || \
    defined(CPU_MK66FN2M0VLQ18) || defined(CPU_MK66FX1M0VLQ18) || defined(CPU_MK66FN2M0VMD18) || defined(CPU_MK66FX1M0VMD18)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0TSI0 = 1|0x100U, /*!< TSI0. */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0UART3Rx = 8|0x100U, /*!< UART3 Receive. */
    kDmaRequestMux0UART3Tx = 9|0x100U, /*!< UART3 Transmit. */
    kDmaRequestMux0UART4 = 10|0x100U, /*!< UART4 Transmit or Receive. */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1Rx = 16|0x100U, /*!< SPI1 Receive. */
    kDmaRequestMux0SPI1Tx = 17|0x100U, /*!< SPI1 Transmit. */
    kDmaRequestMux0I2C0I2C3 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C3 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1TPM1Channel0 = 28|0x100U, /*!< FTM1 C0V and TPM1 C0V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V and TPM1 C0V. */
    kDmaRequestMux0TPM1Channel0 = 28|0x100U, /*!< FTM1 C0V and TPM1 C0V. */
    kDmaRequestMux0FTM1TPM1Channel1 = 29|0x100U, /*!< FTM1 C1V and TPM1 C1V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V and TPM1 C1V. */
    kDmaRequestMux0TPM1Channel1 = 29|0x100U, /*!< FTM1 C1V and TPM1 C1V. */
    kDmaRequestMux0FTM2TPM2Channel0 = 30|0x100U, /*!< FTM2 C0V and TPM2 C0V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V and TPM2 C0V. */
    kDmaRequestMux0TPM2Channel0 = 30|0x100U, /*!< FTM2 C0V and TPM2 C0V. */
    kDmaRequestMux0FTM2TPM2Channel1 = 31|0x100U, /*!< FTM2 C1V and TPM2 C1V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V and TPM2 C1V. */
    kDmaRequestMux0TPM2Channel1 = 31|0x100U, /*!< FTM2 C1V and TPM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6SPI2Rx = 38|0x100U, /*!< FTM3 C6V and SPI2 Receive. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V and SPI2 Receive. */
    kDmaRequestMux0SPI2Rx = 38|0x100U, /*!< FTM3 C6V and SPI2 Receive. */
    kDmaRequestMux0FTM3Channel7SPI2Tx = 39|0x100U, /*!< FTM3 C7V and SPI2 Transmit. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V and SPI2 Transmit. */
    kDmaRequestMux0SPI2Tx = 39|0x100U, /*!< FTM3 C7V and SPI2 Transmit. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2CMP3 = 44|0x100U, /*!< CMP2 and CMP3. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 and CMP3. */
    kDmaRequestMux0CMP3 = 44|0x100U, /*!< CMP2 and CMP3. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1. */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0IEEE1588Timer0 = 54|0x100U, /*!< ENET IEEE 1588 timer 0. */
    kDmaRequestMux0IEEE1588Timer1TPM1Overflow = 55|0x100U, /*!< ENET IEEE 1588 timer 1 and TPM1. */
    kDmaRequestMux0IEEE1588Timer1 = 55|0x100U, /*!< ENET IEEE 1588 timer 1 and TPM1. */
    kDmaRequestMux0TPM1Overflow = 55|0x100U, /*!< ENET IEEE 1588 timer 1 and TPM1. */
    kDmaRequestMux0IEEE1588Timer2TPM2Overflow = 56|0x100U, /*!< ENET IEEE 1588 timer 2 and TPM2. */
    kDmaRequestMux0IEEE1588Timer2 = 56|0x100U, /*!< ENET IEEE 1588 timer 2 and TPM2. */
    kDmaRequestMux0TPM2Overflow = 56|0x100U, /*!< ENET IEEE 1588 timer 2 and TPM2. */
    kDmaRequestMux0IEEE1588Timer3 = 57|0x100U, /*!< ENET IEEE 1588 timer 3. */
    kDmaRequestMux0LPUART0Rx = 58|0x100U, /*!< LPUART0 Receive. */
    kDmaRequestMux0LPUART0Tx = 59|0x100U, /*!< LPUART0 Transmit. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK80FN256CAx15) || defined(CPU_MK80FN256VDC15) || defined(CPU_MK80FN256VLL15) || defined(CPU_MK80FN256VLQ15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0TSI0 = 1|0x100U, /*!< TSI0. */
    kDmaRequestMux0LPUART0Rx = 2|0x100U, /*!< LPUART0 Receive. */
    kDmaRequestMux0LPUART0Tx = 3|0x100U, /*!< LPUART0 Transmit. */
    kDmaRequestMux0LPUART1Rx = 4|0x100U, /*!< LPUART1 Receive. */
    kDmaRequestMux0LPUART1Tx = 5|0x100U, /*!< LPUART1 Transmit. */
    kDmaRequestMux0LPUART2Rx = 6|0x100U, /*!< LPUART2 Receive. */
    kDmaRequestMux0LPUART2Tx = 7|0x100U, /*!< LPUART2 Transmit. */
    kDmaRequestMux0LPUART3Rx = 8|0x100U, /*!< LPUART3 Receive. */
    kDmaRequestMux0LPUART3Tx = 9|0x100U, /*!< LPUART3 Transmit. */
    kDmaRequestMux0LPUART4Rx = 10|0x100U, /*!< LPUART4 Receive. */
    kDmaRequestMux0LPUART4Tx = 11|0x100U, /*!< LPUART4 Transmit. */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1Rx = 16|0x100U, /*!< SPI1 Receive. */
    kDmaRequestMux0SPI1Tx = 17|0x100U, /*!< SPI1 Transmit. */
    kDmaRequestMux0I2C0I2C3 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C3 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0Reserved41 = 41|0x100U, /*!< Reserved41 */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0SPI2Rx = 58|0x100U, /*!< SPI2 Receive. */
    kDmaRequestMux0SPI2Tx = 59|0x100U, /*!< SPI2 Transmit. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1Disable = 0|0x200U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Group1FlexIO0Channel0 = 1|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel1 = 2|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel2 = 3|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel3 = 4|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel4 = 5|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel5 = 6|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel6 = 7|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel7 = 8|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1Reserved9 = 9|0x200U, /*!< Reserved9 */
    kDmaRequestMux0Group1Reserved10 = 10|0x200U, /*!< Reserved10 */
    kDmaRequestMux0Group1Reserved11 = 11|0x200U, /*!< Reserved11 */
    kDmaRequestMux0Group1Reserved12 = 12|0x200U, /*!< Reserved12 */
    kDmaRequestMux0Group1Reserved13 = 13|0x200U, /*!< Reserved13 */
    kDmaRequestMux0Group1Reserved14 = 14|0x200U, /*!< Reserved14 */
    kDmaRequestMux0Group1Reserved15 = 15|0x200U, /*!< Reserved15 */
    kDmaRequestMux0Group1Reserved16 = 16|0x200U, /*!< Reserved16 */
    kDmaRequestMux0Group1Reserved17 = 17|0x200U, /*!< Reserved17 */
    kDmaRequestMux0Group1Reserved18 = 18|0x200U, /*!< Reserved18 */
    kDmaRequestMux0Group1Reserved19 = 19|0x200U, /*!< Reserved19 */
    kDmaRequestMux0Group1EMVSIM0Rx = 20|0x200U, /*!< EMVSIM0 Receive. */
    kDmaRequestMux0Group1EMVSIM0Tx = 21|0x200U, /*!< EMVSIM0 Transmit. */
    kDmaRequestMux0Group1EMVSIM1Rx = 22|0x200U, /*!< EMVSIM1 Receive. */
    kDmaRequestMux0Group1EMVSIM1Tx = 23|0x200U, /*!< EMVSIM1 Transmit. */
    kDmaRequestMux0Group1QSPI0Rx = 24|0x200U, /*!< QuadSPI0 Receive. */
    kDmaRequestMux0Group1QSPI0Tx = 25|0x200U, /*!< QuadSPI0 Transmit. */
    kDmaRequestMux0Group1Reserved26 = 26|0x200U, /*!< Reserved26 */
    kDmaRequestMux0Group1Reserved27 = 27|0x200U, /*!< Reserved27 */
    kDmaRequestMux0Group1SPI0Rx = 28|0x200U, /*!< SPI0 Receive. */
    kDmaRequestMux0Group1SPI0Tx = 29|0x200U, /*!< SPI0 Transmit. */
    kDmaRequestMux0Group1SPI1Rx = 30|0x200U, /*!< SPI1 Receive. */
    kDmaRequestMux0Group1SPI1Tx = 31|0x200U, /*!< SPI1 Transmit. */
    kDmaRequestMux0Group1Reserved32 = 32|0x200U, /*!< Reserved32 */
    kDmaRequestMux0Group1Reserved33 = 33|0x200U, /*!< Reserved33 */
    kDmaRequestMux0Group1Reserved34 = 34|0x200U, /*!< Reserved34 */
    kDmaRequestMux0Group1Reserved35 = 35|0x200U, /*!< Reserved35 */
    kDmaRequestMux0Group1Reserved36 = 36|0x200U, /*!< Reserved36 */
    kDmaRequestMux0Group1Reserved37 = 37|0x200U, /*!< Reserved37 */
    kDmaRequestMux0Group1Reserved38 = 38|0x200U, /*!< Reserved38 */
    kDmaRequestMux0Group1Reserved39 = 39|0x200U, /*!< Reserved39 */
    kDmaRequestMux0Group1Reserved40 = 40|0x200U, /*!< Reserved40 */
    kDmaRequestMux0Group1Reserved41 = 41|0x200U, /*!< Reserved41 */
    kDmaRequestMux0Group1TPM1Channel0 = 42|0x200U, /*!< TPM1 C0V. */
    kDmaRequestMux0Group1TPM1Channel1 = 43|0x200U, /*!< TPM1 C1V. */
    kDmaRequestMux0Group1TPM2Channel0 = 44|0x200U, /*!< TPM2 C0V. */
    kDmaRequestMux0Group1TPM2Channel1 = 45|0x200U, /*!< TPM2 C1V. */
    kDmaRequestMux0Group1Reserved46 = 46|0x200U, /*!< Reserved46 */
    kDmaRequestMux0Group1Reserved47 = 47|0x200U, /*!< Reserved47 */
    kDmaRequestMux0Group1Reserved48 = 48|0x200U, /*!< Reserved48 */
    kDmaRequestMux0Group1Reserved49 = 49|0x200U, /*!< Reserved49 */
    kDmaRequestMux0Group1Reserved50 = 50|0x200U, /*!< Reserved50 */
    kDmaRequestMux0Group1Reserved51 = 51|0x200U, /*!< Reserved51 */
    kDmaRequestMux0Group1Reserved52 = 52|0x200U, /*!< Reserved52 */
    kDmaRequestMux0Group1Reserved53 = 53|0x200U, /*!< Reserved53 */
    kDmaRequestMux0Group1Reserved54 = 54|0x200U, /*!< Reserved54 */
    kDmaRequestMux0Group1TPM1Overflow = 55|0x200U, /*!< TPM1. */
    kDmaRequestMux0Group1TPM2Overflow = 56|0x200U, /*!< TPM2. */
    kDmaRequestMux0Group1Reserved57 = 57|0x200U, /*!< Reserved57 */
    kDmaRequestMux0Group1Reserved58 = 58|0x200U, /*!< Reserved58 */
    kDmaRequestMux0Group1Reserved59 = 59|0x200U, /*!< Reserved59 */
    kDmaRequestMux0Group1AlwaysOn60 = 60|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn61 = 61|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn62 = 62|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn63 = 63|0x200U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MK81FN256CAx15) || defined(CPU_MK81FN256VDC15) || defined(CPU_MK81FN256VLL15) || defined(CPU_MK81FN256VLQ15) || \
    defined(CPU_MK82FN256CAx15) || defined(CPU_MK82FN256VDC15) || defined(CPU_MK82FN256VLL15) || defined(CPU_MK82FN256VLQ15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0TSI0 = 1|0x100U, /*!< TSI0. */
    kDmaRequestMux0LPUART0Rx = 2|0x100U, /*!< LPUART0 Receive. */
    kDmaRequestMux0LPUART0Tx = 3|0x100U, /*!< LPUART0 Transmit. */
    kDmaRequestMux0LPUART1Rx = 4|0x100U, /*!< LPUART1 Receive. */
    kDmaRequestMux0LPUART1Tx = 5|0x100U, /*!< LPUART1 Transmit. */
    kDmaRequestMux0LPUART2Rx = 6|0x100U, /*!< LPUART2 Receive. */
    kDmaRequestMux0LPUART2Tx = 7|0x100U, /*!< LPUART2 Transmit. */
    kDmaRequestMux0LPUART3Rx = 8|0x100U, /*!< LPUART3 Receive. */
    kDmaRequestMux0LPUART3Tx = 9|0x100U, /*!< LPUART3 Transmit. */
    kDmaRequestMux0LPUART4Rx = 10|0x100U, /*!< LPUART4 Receive. */
    kDmaRequestMux0LPUART4Tx = 11|0x100U, /*!< LPUART4 Transmit. */
    kDmaRequestMux0I2S0Rx = 12|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 13|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1Rx = 16|0x100U, /*!< SPI1 Receive. */
    kDmaRequestMux0SPI1Tx = 17|0x100U, /*!< SPI1 Transmit. */
    kDmaRequestMux0I2C0I2C3 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C3 = 18|0x100U, /*!< I2C0 and I2C3. */
    kDmaRequestMux0I2C1I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0I2C2 = 19|0x100U, /*!< I2C1 and I2C2. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0Reserved41 = 41|0x100U, /*!< Reserved41 */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0SPI2Rx = 58|0x100U, /*!< SPI2 Receive. */
    kDmaRequestMux0SPI2Tx = 59|0x100U, /*!< SPI2 Transmit. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1Disable = 0|0x200U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Group1FlexIO0Channel0 = 1|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel1 = 2|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel2 = 3|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel3 = 4|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel4 = 5|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel5 = 6|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel6 = 7|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1FlexIO0Channel7 = 8|0x200U, /*!< FLEXIO0. */
    kDmaRequestMux0Group1Reserved9 = 9|0x200U, /*!< Reserved9 */
    kDmaRequestMux0Group1Reserved10 = 10|0x200U, /*!< Reserved10 */
    kDmaRequestMux0Group1Reserved11 = 11|0x200U, /*!< Reserved11 */
    kDmaRequestMux0Group1Reserved12 = 12|0x200U, /*!< Reserved12 */
    kDmaRequestMux0Group1Reserved13 = 13|0x200U, /*!< Reserved13 */
    kDmaRequestMux0Group1Reserved14 = 14|0x200U, /*!< Reserved14 */
    kDmaRequestMux0Group1Reserved15 = 15|0x200U, /*!< Reserved15 */
    kDmaRequestMux0Group1Reserved16 = 16|0x200U, /*!< Reserved16 */
    kDmaRequestMux0Group1LTC0InputFIFO = 17|0x200U, /*!< LTC0 Input FIFO. */
    kDmaRequestMux0Group1LTC0OutputFIFO = 18|0x200U, /*!< LTC0 Output FIFO. */
    kDmaRequestMux0Group1LTC0PKHA = 19|0x200U, /*!< LTC0 PKHA. */
    kDmaRequestMux0Group1EMVSIM0Rx = 20|0x200U, /*!< EMVSIM0 Receive. */
    kDmaRequestMux0Group1EMVSIM0Tx = 21|0x200U, /*!< EMVSIM0 Transmit. */
    kDmaRequestMux0Group1EMVSIM1Rx = 22|0x200U, /*!< EMVSIM1 Receive. */
    kDmaRequestMux0Group1EMVSIM1Tx = 23|0x200U, /*!< EMVSIM1 Transmit. */
    kDmaRequestMux0Group1QSPI0Rx = 24|0x200U, /*!< QuadSPI0 Receive. */
    kDmaRequestMux0Group1QSPI0Tx = 25|0x200U, /*!< QuadSPI0 Transmit. */
    kDmaRequestMux0Group1Reserved26 = 26|0x200U, /*!< Reserved26 */
    kDmaRequestMux0Group1Reserved27 = 27|0x200U, /*!< Reserved27 */
    kDmaRequestMux0Group1SPI0Rx = 28|0x200U, /*!< SPI0 Receive. */
    kDmaRequestMux0Group1SPI0Tx = 29|0x200U, /*!< SPI0 Transmit. */
    kDmaRequestMux0Group1SPI1Rx = 30|0x200U, /*!< SPI1 Receive. */
    kDmaRequestMux0Group1SPI1Tx = 31|0x200U, /*!< SPI1 Transmit. */
    kDmaRequestMux0Group1Reserved32 = 32|0x200U, /*!< Reserved32 */
    kDmaRequestMux0Group1Reserved33 = 33|0x200U, /*!< Reserved33 */
    kDmaRequestMux0Group1Reserved34 = 34|0x200U, /*!< Reserved34 */
    kDmaRequestMux0Group1Reserved35 = 35|0x200U, /*!< Reserved35 */
    kDmaRequestMux0Group1Reserved36 = 36|0x200U, /*!< Reserved36 */
    kDmaRequestMux0Group1Reserved37 = 37|0x200U, /*!< Reserved37 */
    kDmaRequestMux0Group1Reserved38 = 38|0x200U, /*!< Reserved38 */
    kDmaRequestMux0Group1Reserved39 = 39|0x200U, /*!< Reserved39 */
    kDmaRequestMux0Group1Reserved40 = 40|0x200U, /*!< Reserved40 */
    kDmaRequestMux0Group1Reserved41 = 41|0x200U, /*!< Reserved41 */
    kDmaRequestMux0Group1TPM1Channel0 = 42|0x200U, /*!< TPM1 C0V. */
    kDmaRequestMux0Group1TPM1Channel1 = 43|0x200U, /*!< TPM1 C1V. */
    kDmaRequestMux0Group1TPM2Channel0 = 44|0x200U, /*!< TPM2 C0V. */
    kDmaRequestMux0Group1TPM2Channel1 = 45|0x200U, /*!< TPM2 C1V. */
    kDmaRequestMux0Group1Reserved46 = 46|0x200U, /*!< Reserved46 */
    kDmaRequestMux0Group1Reserved47 = 47|0x200U, /*!< Reserved47 */
    kDmaRequestMux0Group1Reserved48 = 48|0x200U, /*!< Reserved48 */
    kDmaRequestMux0Group1Reserved49 = 49|0x200U, /*!< Reserved49 */
    kDmaRequestMux0Group1Reserved50 = 50|0x200U, /*!< Reserved50 */
    kDmaRequestMux0Group1Reserved51 = 51|0x200U, /*!< Reserved51 */
    kDmaRequestMux0Group1Reserved52 = 52|0x200U, /*!< Reserved52 */
    kDmaRequestMux0Group1Reserved53 = 53|0x200U, /*!< Reserved53 */
    kDmaRequestMux0Group1Reserved54 = 54|0x200U, /*!< Reserved54 */
    kDmaRequestMux0Group1TPM1Overflow = 55|0x200U, /*!< TPM1. */
    kDmaRequestMux0Group1TPM2Overflow = 56|0x200U, /*!< TPM2. */
    kDmaRequestMux0Group1Reserved57 = 57|0x200U, /*!< Reserved57 */
    kDmaRequestMux0Group1Reserved58 = 58|0x200U, /*!< Reserved58 */
    kDmaRequestMux0Group1Reserved59 = 59|0x200U, /*!< Reserved59 */
    kDmaRequestMux0Group1AlwaysOn60 = 60|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn61 = 61|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn62 = 62|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn63 = 63|0x200U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MKV10Z128VLC7) || defined(CPU_MKV10Z128VFM7) || defined(CPU_MKV10Z64VLC7) || defined(CPU_MKV10Z64VFM7) || \
    defined(CPU_MKV10Z128VLF7) || defined(CPU_MKV10Z64VLF7) || defined(CPU_MKV10Z128VLH7) || defined(CPU_MKV10Z64VLH7) || \
    defined(CPU_MKV11Z128VLC7) || defined(CPU_MKV11Z128VFM7) || defined(CPU_MKV11Z64VLC7) || defined(CPU_MKV11Z64VFM7) || \
    defined(CPU_MKV11Z128VLF7) || defined(CPU_MKV11Z64VLF7) || defined(CPU_MKV11Z128VLH7) || defined(CPU_MKV11Z64VLH7)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART 0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART 0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART 1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART 1 transmit complete */
    kDmaRequestMux0Reserved6 = 6|0x100U, /*!< Reserved6 */
    kDmaRequestMux0Reserved7 = 7|0x100U, /*!< Reserved7 */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0Reserved14 = 14|0x100U, /*!< Reserved14 */
    kDmaRequestMux0Reserved15 = 15|0x100U, /*!< Reserved15 */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0Reserved18 = 18|0x100U, /*!< Reserved18 */
    kDmaRequestMux0Reserved19 = 19|0x100U, /*!< Reserved19 */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM4Channel0 = 30|0x100U, /*!< FTM4 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM4Channel1 = 31|0x100U, /*!< FTM4 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM3Channel0 = 36|0x100U, /*!< FTM3 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM3Channel1 = 37|0x100U, /*!< FTM3 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM3Channel2 = 38|0x100U, /*!< FTM3 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM3Channel3 = 39|0x100U, /*!< FTM3 channel 3 event (CMP or CAP) */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC 0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC 1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB1 = 47|0x100U, /*!< PDB1 programmable interrupt delay event */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0FTM3Channel4 = 54|0x100U, /*!< FTM3 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM3Channel5 = 55|0x100U, /*!< FTM3 channel 5 event (CMP or CAP) */
    kDmaRequestMux0FTM5Channel0 = 56|0x100U, /*!< FTM5 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM5Channel1 = 57|0x100U, /*!< FTM5 channel 1 event (CMP or CAP) */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MKV10Z16VFM7) || defined(CPU_MKV10Z16VLC7) || defined(CPU_MKV10Z16VLF7) || defined(CPU_MKV10Z32VFM7) || \
    defined(CPU_MKV10Z32VLC7) || defined(CPU_MKV10Z32VLF7)
    kDmaRequestMux0Disable = 0|0x100U, /*!< Disable */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART 0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART 0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART 1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART 1 transmit complete */
    kDmaRequestMux0Reserved6 = 6|0x100U, /*!< Reserved6 */
    kDmaRequestMux0Reserved7 = 7|0x100U, /*!< Reserved7 */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0Reserved14 = 14|0x100U, /*!< Reserved14 */
    kDmaRequestMux0Reserved15 = 15|0x100U, /*!< Reserved15 */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 transmit complete */
    kDmaRequestMux0Reserved18 = 18|0x100U, /*!< Reserved18 */
    kDmaRequestMux0Reserved19 = 19|0x100U, /*!< Reserved19 */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0 transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event (CMP or CAP) */
    kDmaRequestMux0Reserved30 = 30|0x100U, /*!< Reserved30 */
    kDmaRequestMux0Reserved31 = 31|0x100U, /*!< Reserved31 */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 channel 0 event (CMP or CAP) */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 channel 1 event (CMP or CAP) */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC 0 conversion complete */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC 1 conversion complete */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 Output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 Output */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0 buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0Reserved47 = 47|0x100U, /*!< Reserved47 */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0 programmable interrupt delay event */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< Always enabled 54 */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< Always enabled 55 */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< Always enabled 56 */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< Always enabled 57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Always enabled 58 */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Always enabled 59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Always enabled 60 */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Always enabled 61 */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Always enabled 62 */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Always enabled 63 */
#elif defined(CPU_MKV30F128VFM10) || defined(CPU_MKV30F64VFM10) || defined(CPU_MKV30F128VLF10) || defined(CPU_MKV30F64VLF10) || \
    defined(CPU_MKV30F128VLH10) || defined(CPU_MKV30F64VLH10)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0Reserved6 = 6|0x100U, /*!< Reserved6 */
    kDmaRequestMux0Reserved7 = 7|0x100U, /*!< Reserved7 */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0Reserved16 = 16|0x100U, /*!< Reserved16 */
    kDmaRequestMux0Reserved17 = 17|0x100U, /*!< Reserved17 */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0Reserved19 = 19|0x100U, /*!< Reserved19 */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0Reserved26 = 26|0x100U, /*!< Reserved26 */
    kDmaRequestMux0Reserved27 = 27|0x100U, /*!< Reserved27 */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0Reserved32 = 32|0x100U, /*!< Reserved32 */
    kDmaRequestMux0Reserved33 = 33|0x100U, /*!< Reserved33 */
    kDmaRequestMux0Reserved34 = 34|0x100U, /*!< Reserved34 */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0Reserved47 = 47|0x100U, /*!< Reserved47 */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0Reserved58 = 58|0x100U, /*!< Reserved58 */
    kDmaRequestMux0Reserved59 = 59|0x100U, /*!< Reserved59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MKV31F128VLH10) || defined(CPU_MKV31F128VLL10) || defined(CPU_MKV31F256VLH12) || defined(CPU_MKV31F256VLL12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0Reserved17 = 17|0x100U, /*!< Reserved17 */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0Reserved32 = 32|0x100U, /*!< Reserved32 */
    kDmaRequestMux0Reserved33 = 33|0x100U, /*!< Reserved33 */
    kDmaRequestMux0Reserved34 = 34|0x100U, /*!< Reserved34 */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0Reserved47 = 47|0x100U, /*!< Reserved47 */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0LPUART0Rx = 58|0x100U, /*!< LPUART0 Receive. */
    kDmaRequestMux0LPUART0Tx = 59|0x100U, /*!< LPUART0 Transmit. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MKV31F512VLH12) || defined(CPU_MKV31F512VLL12)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0SPI0Rx = 14|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 15|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1 = 16|0x100U, /*!< SPI1 Transmit or Receive. */
    kDmaRequestMux0Reserved17 = 17|0x100U, /*!< Reserved17 */
    kDmaRequestMux0I2C0 = 18|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1 = 19|0x100U, /*!< I2C1. */
    kDmaRequestMux0FTM0Channel0 = 20|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 21|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 22|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 23|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 24|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 25|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 26|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 27|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 28|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 29|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 30|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 31|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0FTM3Channel0 = 32|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 33|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 34|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 35|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0FTM3Channel4 = 36|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 37|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 38|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 39|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0ADC1 = 41|0x100U, /*!< ADC1. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0DAC1 = 46|0x100U, /*!< DAC1. */
    kDmaRequestMux0Reserved47 = 47|0x100U, /*!< Reserved47 */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0LPUART0Rx = 58|0x100U, /*!< LPUART0 Receive. */
    kDmaRequestMux0LPUART0Tx = 59|0x100U, /*!< LPUART0 Transmit. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MKV40F128VLH15) || defined(CPU_MKV40F256VLH15) || defined(CPU_MKV40F64VLH15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMA requests are disabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0Reserved6 = 6|0x100U, /*!< Reserved6 */
    kDmaRequestMux0Reserved7 = 7|0x100U, /*!< Reserved7 */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0CAN0Rx = 14|0x100U, /*!< CAN0 reach receiever mailbox level */
    kDmaRequestMux0Reserved15 = 15|0x100U, /*!< Reserved15 */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI transmit complete */
    kDmaRequestMux0XBARAOut0 = 18|0x100U, /*!< XBARA output 0 */
    kDmaRequestMux0XBARAOut1 = 19|0x100U, /*!< XBARA output 1 */
    kDmaRequestMux0XBARAOut2 = 20|0x100U, /*!< XBARA output 2 */
    kDmaRequestMux0XBARAOut3 = 21|0x100U, /*!< XBARA output 3 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3 output */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADCA = 40|0x100U, /*!< ADC converter A end of scan */
    kDmaRequestMux0ADCB = 41|0x100U, /*!< ADC converter B end of scan */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 output */
    kDmaRequestMux0Reserved45 = 45|0x100U, /*!< Reserved45 */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB0 = 47|0x100U, /*!< PDB0 channel 0 output trigger */
    kDmaRequestMux0PDB1 = 48|0x100U, /*!< PDB1 channel 0 output trigger */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Slot 58 is always enabled */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Slot 59 is always enabled */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Slot 60 is always enabled */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Slot 61 is always enabled */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Slot 62 is always enabled */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Slot 63 is always enabled */
#elif defined(CPU_MKV40F128VLL15) || defined(CPU_MKV40F256VLL15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMA requests are disabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0Reserved6 = 6|0x100U, /*!< Reserved6 */
    kDmaRequestMux0Reserved7 = 7|0x100U, /*!< Reserved7 */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0CAN0Rx = 14|0x100U, /*!< CAN0 reach receiever mailbox level */
    kDmaRequestMux0CAN1Rx = 15|0x100U, /*!< CAN1 reach receiever mailbox level */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI transmit complete */
    kDmaRequestMux0XBARAOut0 = 18|0x100U, /*!< XBARA output 0 */
    kDmaRequestMux0XBARAOut1 = 19|0x100U, /*!< XBARA output 1 */
    kDmaRequestMux0XBARAOut2 = 20|0x100U, /*!< XBARA output 2 */
    kDmaRequestMux0XBARAOut3 = 21|0x100U, /*!< XBARA output 3 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3 output */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0FTM3Channel0 = 36|0x100U, /*!< FTM3 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel1 = 37|0x100U, /*!< FTM3 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel2 = 38|0x100U, /*!< FTM3 channel 2 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel3 = 39|0x100U, /*!< FTM3 channel 3 event  (CMP or CAP) */
    kDmaRequestMux0ADCA = 40|0x100U, /*!< ADC converter A end of scan */
    kDmaRequestMux0ADCB = 41|0x100U, /*!< ADC converter B end of scan */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 output */
    kDmaRequestMux0Reserved45 = 45|0x100U, /*!< Reserved45 */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB0 = 47|0x100U, /*!< PDB0 channel 0 output trigger */
    kDmaRequestMux0PDB1 = 48|0x100U, /*!< PDB1 channel 0 output trigger */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0FTM3Channel4 = 54|0x100U, /*!< FTM3 channel 4 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel5 = 55|0x100U, /*!< FTM3 channel 5 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel6 = 56|0x100U, /*!< FTM3 channel 6 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel7 = 57|0x100U, /*!< FTM3 channel 7 event  (CMP or CAP) */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Slot 58 is always enabled */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Slot 59 is always enabled */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Slot 60 is always enabled */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Slot 61 is always enabled */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Slot 62 is always enabled */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Slot 63 is always enabled */
#elif defined(CPU_MKV43F128VLH15) || defined(CPU_MKV43F64VLH15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMA requests are disabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0PWMA0WR = 6|0x100U, /*!< PWMA submodule 0 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA1WR = 7|0x100U, /*!< PWMA submodule 1 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA2WR = 8|0x100U, /*!< PWMA submodule 2 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA3WR = 9|0x100U, /*!< PWMA submodule 3 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA0CP = 10|0x100U, /*!< PWMA submodule 0 read request on capture FIFO marker */
    kDmaRequestMux0PWMA1CP = 11|0x100U, /*!< PWMA submodule 1 read request on capture FIFO marker */
    kDmaRequestMux0PWMA2CP = 12|0x100U, /*!< PWMA submodule 2 read request on capture FIFO marker */
    kDmaRequestMux0PWMA3CP = 13|0x100U, /*!< PWMA submodule 3 read request on capture FIFO marker */
    kDmaRequestMux0CAN0Rx = 14|0x100U, /*!< CAN0 reach receiever mailbox level */
    kDmaRequestMux0Reserved15 = 15|0x100U, /*!< Reserved15 */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI transmit complete */
    kDmaRequestMux0XBARAOut0 = 18|0x100U, /*!< XBARA output 0 */
    kDmaRequestMux0XBARAOut1 = 19|0x100U, /*!< XBARA output 1 */
    kDmaRequestMux0XBARAOut2 = 20|0x100U, /*!< XBARA output 2 */
    kDmaRequestMux0XBARAOut3 = 21|0x100U, /*!< XBARA output 3 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0Reserved24 = 24|0x100U, /*!< Reserved24 */
    kDmaRequestMux0Reserved25 = 25|0x100U, /*!< Reserved25 */
    kDmaRequestMux0Reserved26 = 26|0x100U, /*!< Reserved26 */
    kDmaRequestMux0Reserved27 = 27|0x100U, /*!< Reserved27 */
    kDmaRequestMux0Reserved28 = 28|0x100U, /*!< Reserved28 */
    kDmaRequestMux0Reserved29 = 29|0x100U, /*!< Reserved29 */
    kDmaRequestMux0Reserved30 = 30|0x100U, /*!< Reserved30 */
    kDmaRequestMux0Reserved31 = 31|0x100U, /*!< Reserved31 */
    kDmaRequestMux0Reserved32 = 32|0x100U, /*!< Reserved32 */
    kDmaRequestMux0Reserved33 = 33|0x100U, /*!< Reserved33 */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3 output */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADCA = 40|0x100U, /*!< ADC converter A end of scan */
    kDmaRequestMux0ADCB = 41|0x100U, /*!< ADC converter B end of scan */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 output */
    kDmaRequestMux0Reserved45 = 45|0x100U, /*!< Reserved45 */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB0 = 47|0x100U, /*!< PDB0 channel 0 output trigger */
    kDmaRequestMux0PDB1 = 48|0x100U, /*!< PDB1 channel 0 output trigger */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Slot 58 is always enabled */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Slot 59 is always enabled */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Slot 60 is always enabled */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Slot 61 is always enabled */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Slot 62 is always enabled */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Slot 63 is always enabled */
#elif defined(CPU_MKV43F128VLL15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMA requests are disabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0PWMA0WR = 6|0x100U, /*!< PWMA submodule 0 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA1WR = 7|0x100U, /*!< PWMA submodule 1 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA2WR = 8|0x100U, /*!< PWMA submodule 2 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA3WR = 9|0x100U, /*!< PWMA submodule 3 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA0CP = 10|0x100U, /*!< PWMA submodule 0 read request on capture FIFO marker */
    kDmaRequestMux0PWMA1CP = 11|0x100U, /*!< PWMA submodule 1 read request on capture FIFO marker */
    kDmaRequestMux0PWMA2CP = 12|0x100U, /*!< PWMA submodule 2 read request on capture FIFO marker */
    kDmaRequestMux0PWMA3CP = 13|0x100U, /*!< PWMA submodule 3 read request on capture FIFO marker */
    kDmaRequestMux0CAN0Rx = 14|0x100U, /*!< CAN0 reach receiever mailbox level */
    kDmaRequestMux0CAN1Rx = 15|0x100U, /*!< CAN1 reach receiever mailbox level */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI transmit complete */
    kDmaRequestMux0XBARAOut0 = 18|0x100U, /*!< XBARA output 0 */
    kDmaRequestMux0XBARAOut1 = 19|0x100U, /*!< XBARA output 1 */
    kDmaRequestMux0XBARAOut2 = 20|0x100U, /*!< XBARA output 2 */
    kDmaRequestMux0XBARAOut3 = 21|0x100U, /*!< XBARA output 3 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0Reserved24 = 24|0x100U, /*!< Reserved24 */
    kDmaRequestMux0Reserved25 = 25|0x100U, /*!< Reserved25 */
    kDmaRequestMux0Reserved26 = 26|0x100U, /*!< Reserved26 */
    kDmaRequestMux0Reserved27 = 27|0x100U, /*!< Reserved27 */
    kDmaRequestMux0Reserved28 = 28|0x100U, /*!< Reserved28 */
    kDmaRequestMux0Reserved29 = 29|0x100U, /*!< Reserved29 */
    kDmaRequestMux0Reserved30 = 30|0x100U, /*!< Reserved30 */
    kDmaRequestMux0Reserved31 = 31|0x100U, /*!< Reserved31 */
    kDmaRequestMux0Reserved32 = 32|0x100U, /*!< Reserved32 */
    kDmaRequestMux0Reserved33 = 33|0x100U, /*!< Reserved33 */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3 output */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADCA = 40|0x100U, /*!< ADC converter A end of scan */
    kDmaRequestMux0ADCB = 41|0x100U, /*!< ADC converter B end of scan */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 output */
    kDmaRequestMux0Reserved45 = 45|0x100U, /*!< Reserved45 */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB0 = 47|0x100U, /*!< PDB0 channel 0 output trigger */
    kDmaRequestMux0PDB1 = 48|0x100U, /*!< PDB1 channel 0 output trigger */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Slot 58 is always enabled */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Slot 59 is always enabled */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Slot 60 is always enabled */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Slot 61 is always enabled */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Slot 62 is always enabled */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Slot 63 is always enabled */
#elif defined(CPU_MKV44F128VLH15) || defined(CPU_MKV44F128VLL15) || defined(CPU_MKV44F64VLH15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMA requests are disabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0PWMA0WR = 6|0x100U, /*!< PWMA submodule 0 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA1WR = 7|0x100U, /*!< PWMA submodule 1 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA2WR = 8|0x100U, /*!< PWMA submodule 2 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA3WR = 9|0x100U, /*!< PWMA submodule 3 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA0CP = 10|0x100U, /*!< PWMA submodule 0 read request on capture FIFO marker */
    kDmaRequestMux0PWMA1CP = 11|0x100U, /*!< PWMA submodule 1 read request on capture FIFO marker */
    kDmaRequestMux0PWMA2CP = 12|0x100U, /*!< PWMA submodule 2 read request on capture FIFO marker */
    kDmaRequestMux0PWMA3CP = 13|0x100U, /*!< PWMA submodule 3 read request on capture FIFO marker */
    kDmaRequestMux0CAN0Rx = 14|0x100U, /*!< CAN0 reach receiever mailbox level */
    kDmaRequestMux0Reserved15 = 15|0x100U, /*!< Reserved15 */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI transmit complete */
    kDmaRequestMux0XBARAOut0 = 18|0x100U, /*!< XBARA output 0 */
    kDmaRequestMux0XBARAOut1 = 19|0x100U, /*!< XBARA output 1 */
    kDmaRequestMux0XBARAOut2 = 20|0x100U, /*!< XBARA output 2 */
    kDmaRequestMux0XBARAOut3 = 21|0x100U, /*!< XBARA output 3 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0Reserved24 = 24|0x100U, /*!< Reserved24 */
    kDmaRequestMux0Reserved25 = 25|0x100U, /*!< Reserved25 */
    kDmaRequestMux0Reserved26 = 26|0x100U, /*!< Reserved26 */
    kDmaRequestMux0Reserved27 = 27|0x100U, /*!< Reserved27 */
    kDmaRequestMux0Reserved28 = 28|0x100U, /*!< Reserved28 */
    kDmaRequestMux0Reserved29 = 29|0x100U, /*!< Reserved29 */
    kDmaRequestMux0Reserved30 = 30|0x100U, /*!< Reserved30 */
    kDmaRequestMux0Reserved31 = 31|0x100U, /*!< Reserved31 */
    kDmaRequestMux0Reserved32 = 32|0x100U, /*!< Reserved32 */
    kDmaRequestMux0Reserved33 = 33|0x100U, /*!< Reserved33 */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3 output */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADCA = 40|0x100U, /*!< ADC converter A end of scan */
    kDmaRequestMux0ADCB = 41|0x100U, /*!< ADC converter B end of scan */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB0 = 47|0x100U, /*!< PDB0 channel 0 output trigger */
    kDmaRequestMux0PDB1 = 48|0x100U, /*!< PDB1 channel 0 output trigger */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Slot 58 is always enabled */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Slot 59 is always enabled */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Slot 60 is always enabled */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Slot 61 is always enabled */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Slot 62 is always enabled */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Slot 63 is always enabled */
#elif defined(CPU_MKV45F128VLH15) || defined(CPU_MKV45F256VLH15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMA requests are disabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0PWMA0WR = 6|0x100U, /*!< PWMA submodule 0 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA1WR = 7|0x100U, /*!< PWMA submodule 1 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA2WR = 8|0x100U, /*!< PWMA submodule 2 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA3WR = 9|0x100U, /*!< PWMA submodule 3 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA0CP = 10|0x100U, /*!< PWMA submodule 0 read request on capture FIFO marker */
    kDmaRequestMux0PWMA1CP = 11|0x100U, /*!< PWMA submodule 1 read request on capture FIFO marker */
    kDmaRequestMux0PWMA2CP = 12|0x100U, /*!< PWMA submodule 2 read request on capture FIFO marker */
    kDmaRequestMux0PWMA3CP = 13|0x100U, /*!< PWMA submodule 3 read request on capture FIFO marker */
    kDmaRequestMux0CAN0Rx = 14|0x100U, /*!< CAN0 reach receiever mailbox level */
    kDmaRequestMux0Reserved15 = 15|0x100U, /*!< Reserved15 */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI transmit complete */
    kDmaRequestMux0XBARAOut0 = 18|0x100U, /*!< XBARA output 0 */
    kDmaRequestMux0XBARAOut1 = 19|0x100U, /*!< XBARA output 1 */
    kDmaRequestMux0XBARAOut2 = 20|0x100U, /*!< XBARA output 2 */
    kDmaRequestMux0XBARAOut3 = 21|0x100U, /*!< XBARA output 3 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3 output */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADCA = 40|0x100U, /*!< ADC converter A end of scan */
    kDmaRequestMux0ADCB = 41|0x100U, /*!< ADC converter B end of scan */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 output */
    kDmaRequestMux0Reserved45 = 45|0x100U, /*!< Reserved45 */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB0 = 47|0x100U, /*!< PDB0 channel 0 output trigger */
    kDmaRequestMux0PDB1 = 48|0x100U, /*!< PDB1 channel 0 output trigger */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Slot 58 is always enabled */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Slot 59 is always enabled */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Slot 60 is always enabled */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Slot 61 is always enabled */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Slot 62 is always enabled */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Slot 63 is always enabled */
#elif defined(CPU_MKV45F128VLL15) || defined(CPU_MKV45F256VLL15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMA requests are disabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0PWMA0WR = 6|0x100U, /*!< PWMA submodule 0 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA1WR = 7|0x100U, /*!< PWMA submodule 1 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA2WR = 8|0x100U, /*!< PWMA submodule 2 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA3WR = 9|0x100U, /*!< PWMA submodule 3 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA0CP = 10|0x100U, /*!< PWMA submodule 0 read request on capture FIFO marker */
    kDmaRequestMux0PWMA1CP = 11|0x100U, /*!< PWMA submodule 1 read request on capture FIFO marker */
    kDmaRequestMux0PWMA2CP = 12|0x100U, /*!< PWMA submodule 2 read request on capture FIFO marker */
    kDmaRequestMux0PWMA3CP = 13|0x100U, /*!< PWMA submodule 3 read request on capture FIFO marker */
    kDmaRequestMux0CAN0Rx = 14|0x100U, /*!< CAN0 reach receiever mailbox level */
    kDmaRequestMux0CAN1Rx = 15|0x100U, /*!< CAN1 reach receiever mailbox level */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI transmit complete */
    kDmaRequestMux0XBARAOut0 = 18|0x100U, /*!< XBARA output 0 */
    kDmaRequestMux0XBARAOut1 = 19|0x100U, /*!< XBARA output 1 */
    kDmaRequestMux0XBARAOut2 = 20|0x100U, /*!< XBARA output 2 */
    kDmaRequestMux0XBARAOut3 = 21|0x100U, /*!< XBARA output 3 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3 output */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0FTM3Channel0 = 36|0x100U, /*!< FTM3 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel1 = 37|0x100U, /*!< FTM3 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel2 = 38|0x100U, /*!< FTM3 channel 2 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel3 = 39|0x100U, /*!< FTM3 channel 3 event  (CMP or CAP) */
    kDmaRequestMux0ADCA = 40|0x100U, /*!< ADC converter A end of scan */
    kDmaRequestMux0ADCB = 41|0x100U, /*!< ADC converter B end of scan */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 output */
    kDmaRequestMux0Reserved45 = 45|0x100U, /*!< Reserved45 */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB0 = 47|0x100U, /*!< PDB0 channel 0 output trigger */
    kDmaRequestMux0PDB1 = 48|0x100U, /*!< PDB1 channel 0 output trigger */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0FTM3Channel4 = 54|0x100U, /*!< FTM3 channel 4 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel5 = 55|0x100U, /*!< FTM3 channel 5 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel6 = 56|0x100U, /*!< FTM3 channel 6 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel7 = 57|0x100U, /*!< FTM3 channel 7 event  (CMP or CAP) */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Slot 58 is always enabled */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Slot 59 is always enabled */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Slot 60 is always enabled */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Slot 61 is always enabled */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Slot 62 is always enabled */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Slot 63 is always enabled */
#elif defined(CPU_MKV46F128VLH15) || defined(CPU_MKV46F256VLH15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMA requests are disabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0PWMA0WR = 6|0x100U, /*!< PWMA submodule 0 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA1WR = 7|0x100U, /*!< PWMA submodule 1 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA2WR = 8|0x100U, /*!< PWMA submodule 2 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA3WR = 9|0x100U, /*!< PWMA submodule 3 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA0CP = 10|0x100U, /*!< PWMA submodule 0 read request on capture FIFO marker */
    kDmaRequestMux0PWMA1CP = 11|0x100U, /*!< PWMA submodule 1 read request on capture FIFO marker */
    kDmaRequestMux0PWMA2CP = 12|0x100U, /*!< PWMA submodule 2 read request on capture FIFO marker */
    kDmaRequestMux0PWMA3CP = 13|0x100U, /*!< PWMA submodule 3 read request on capture FIFO marker */
    kDmaRequestMux0CAN0Rx = 14|0x100U, /*!< CAN0 reach receiever mailbox level */
    kDmaRequestMux0CAN1Rx = 15|0x100U, /*!< CAN1 reach receiever mailbox level */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI transmit complete */
    kDmaRequestMux0XBARAOut0 = 18|0x100U, /*!< XBARA output 0 */
    kDmaRequestMux0XBARAOut1 = 19|0x100U, /*!< XBARA output 1 */
    kDmaRequestMux0XBARAOut2 = 20|0x100U, /*!< XBARA output 2 */
    kDmaRequestMux0XBARAOut3 = 21|0x100U, /*!< XBARA output 3 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3 output */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADCA = 40|0x100U, /*!< ADC converter A end of scan */
    kDmaRequestMux0ADCB = 41|0x100U, /*!< ADC converter B end of scan */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB0 = 47|0x100U, /*!< PDB0 channel 0 output trigger */
    kDmaRequestMux0PDB1 = 48|0x100U, /*!< PDB1 channel 0 output trigger */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0Reserved54 = 54|0x100U, /*!< Reserved54 */
    kDmaRequestMux0Reserved55 = 55|0x100U, /*!< Reserved55 */
    kDmaRequestMux0Reserved56 = 56|0x100U, /*!< Reserved56 */
    kDmaRequestMux0Reserved57 = 57|0x100U, /*!< Reserved57 */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Slot 58 is always enabled */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Slot 59 is always enabled */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Slot 60 is always enabled */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Slot 61 is always enabled */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Slot 62 is always enabled */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Slot 63 is always enabled */
#elif defined(CPU_MKV46F128VLL15) || defined(CPU_MKV46F256VLL15)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMA requests are disabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 receive complete */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 transmit complete */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 receive complete */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 transmit complete */
    kDmaRequestMux0PWMA0WR = 6|0x100U, /*!< PWMA submodule 0 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA1WR = 7|0x100U, /*!< PWMA submodule 1 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA2WR = 8|0x100U, /*!< PWMA submodule 2 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA3WR = 9|0x100U, /*!< PWMA submodule 3 write request on beginning of reload cycle */
    kDmaRequestMux0PWMA0CP = 10|0x100U, /*!< PWMA submodule 0 read request on capture FIFO marker */
    kDmaRequestMux0PWMA1CP = 11|0x100U, /*!< PWMA submodule 1 read request on capture FIFO marker */
    kDmaRequestMux0PWMA2CP = 12|0x100U, /*!< PWMA submodule 2 read request on capture FIFO marker */
    kDmaRequestMux0PWMA3CP = 13|0x100U, /*!< PWMA submodule 3 read request on capture FIFO marker */
    kDmaRequestMux0CAN0Rx = 14|0x100U, /*!< CAN0 reach receiever mailbox level */
    kDmaRequestMux0CAN1Rx = 15|0x100U, /*!< CAN1 reach receiever mailbox level */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI receive complete */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI transmit complete */
    kDmaRequestMux0XBARAOut0 = 18|0x100U, /*!< XBARA output 0 */
    kDmaRequestMux0XBARAOut1 = 19|0x100U, /*!< XBARA output 1 */
    kDmaRequestMux0XBARAOut2 = 20|0x100U, /*!< XBARA output 2 */
    kDmaRequestMux0XBARAOut3 = 21|0x100U, /*!< XBARA output 3 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C transmission complete */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 channel 2 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 channel 3 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 channel 4 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 channel 5 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 channel 6 event  (CMP or CAP) */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 channel 7 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3 output */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0FTM3Channel0 = 36|0x100U, /*!< FTM3 channel 0 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel1 = 37|0x100U, /*!< FTM3 channel 1 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel2 = 38|0x100U, /*!< FTM3 channel 2 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel3 = 39|0x100U, /*!< FTM3 channel 3 event  (CMP or CAP) */
    kDmaRequestMux0ADCA = 40|0x100U, /*!< ADC converter A end of scan */
    kDmaRequestMux0ADCB = 41|0x100U, /*!< ADC converter B end of scan */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0 output */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1 output */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2 output */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC buffer pointer reaches upper or lower limit */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB0 = 47|0x100U, /*!< PDB0 channel 0 output trigger */
    kDmaRequestMux0PDB1 = 48|0x100U, /*!< PDB1 channel 0 output trigger */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PORTA rising, falling or both edges */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PORTB rising, falling or both edges */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PORTC rising, falling or both edges */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PORTD rising, falling or both edges */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PORTE rising, falling or both edges */
    kDmaRequestMux0FTM3Channel4 = 54|0x100U, /*!< FTM3 channel 4 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel5 = 55|0x100U, /*!< FTM3 channel 5 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel6 = 56|0x100U, /*!< FTM3 channel 6 event  (CMP or CAP) */
    kDmaRequestMux0FTM3Channel7 = 57|0x100U, /*!< FTM3 channel 7 event  (CMP or CAP) */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< Slot 58 is always enabled */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< Slot 59 is always enabled */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< Slot 60 is always enabled */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< Slot 61 is always enabled */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< Slot 62 is always enabled */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< Slot 63 is always enabled */
#elif defined(CPU_MKV56F1M0VLL22) || defined(CPU_MKV56F512VLL22) || defined(CPU_MKV56F1M0VLQ22) || defined(CPU_MKV56F512VLQ22) || \
    defined(CPU_MKV56F1M0VMD22) || defined(CPU_MKV56F512VMD22)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0PWM0WR0 = 6|0x100U, /*!< PWM0 Write Request 0. */
    kDmaRequestMux0PWM0WR1 = 7|0x100U, /*!< PWM0 Write Request 1. */
    kDmaRequestMux0PWM0WR2 = 8|0x100U, /*!< PWM0 Write Request 2. */
    kDmaRequestMux0PWM0WR3 = 9|0x100U, /*!< PWM0 Write Request 3. */
    kDmaRequestMux0PWM0CP0 = 10|0x100U, /*!< PWM0 Capture 0. */
    kDmaRequestMux0PWM0CP1 = 11|0x100U, /*!< PWM0 Capture 1. */
    kDmaRequestMux0PWM0CP2 = 12|0x100U, /*!< PWM0 Capture 2. */
    kDmaRequestMux0PWM0CP3 = 13|0x100U, /*!< PWM0 Capture 3. */
    kDmaRequestMux0CAN0 = 14|0x100U, /*!< CAN0. */
    kDmaRequestMux0CAN1 = 15|0x100U, /*!< CAN1. */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0Reserved18 = 18|0x100U, /*!< Reserved18 */
    kDmaRequestMux0Reserved19 = 19|0x100U, /*!< Reserved19 */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0. */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3. */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0FTM3Channel0 = 36|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 37|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 38|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 39|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0HSADC0A = 40|0x100U, /*!< HSADC0. */
    kDmaRequestMux0HSADC0B = 41|0x100U, /*!< HSADC0. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB1 = 47|0x100U, /*!< PDB1. */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0FTM3Channel4 = 54|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 55|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 56|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 57|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0Reserved58 = 58|0x100U, /*!< Reserved58 */
    kDmaRequestMux0Reserved59 = 59|0x100U, /*!< Reserved59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1Disable = 0|0x200U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Group1Reserved1 = 1|0x200U, /*!< Reserved1 */
    kDmaRequestMux0Group1UART2Rx = 2|0x200U, /*!< UART2 Receive. */
    kDmaRequestMux0Group1UART2Tx = 3|0x200U, /*!< UART2 Transmit. */
    kDmaRequestMux0Group1UART3Rx = 4|0x200U, /*!< UART3 Receive. */
    kDmaRequestMux0Group1UART3Tx = 5|0x200U, /*!< UART3 Transmit. */
    kDmaRequestMux0Group1PWM1WR0 = 6|0x200U, /*!< PWM1 Write Request 0. */
    kDmaRequestMux0Group1PWM1WR1 = 7|0x200U, /*!< PWM1 Write Request 1. */
    kDmaRequestMux0Group1PWM1WR2 = 8|0x200U, /*!< PWM1 Write Request 2. */
    kDmaRequestMux0Group1PWM1WR3 = 9|0x200U, /*!< PWM1 Write Request 3. */
    kDmaRequestMux0Group1PWM1CP0 = 10|0x200U, /*!< PWM1 Capture 0. */
    kDmaRequestMux0Group1PWM1CP1 = 11|0x200U, /*!< PWM1 Capture 1. */
    kDmaRequestMux0Group1PWM1CP2 = 12|0x200U, /*!< PWM1 Capture 2. */
    kDmaRequestMux0Group1PWM1CP3 = 13|0x200U, /*!< PWM1 Capture 3. */
    kDmaRequestMux0Group1Reserved14 = 14|0x200U, /*!< Reserved14 */
    kDmaRequestMux0Group1Reserved15 = 15|0x200U, /*!< Reserved15 */
    kDmaRequestMux0Group1SPI1Rx = 16|0x200U, /*!< SPI1 Receive. */
    kDmaRequestMux0Group1SPI1Tx = 17|0x200U, /*!< SPI1 Transmit. */
    kDmaRequestMux0Group1Reserved18 = 18|0x200U, /*!< Reserved18 */
    kDmaRequestMux0Group1Reserved19 = 19|0x200U, /*!< Reserved19 */
    kDmaRequestMux0Group1Reserved20 = 20|0x200U, /*!< Reserved20 */
    kDmaRequestMux0Group1Reserved21 = 21|0x200U, /*!< Reserved21 */
    kDmaRequestMux0Group1I2C1 = 22|0x200U, /*!< I2C1. */
    kDmaRequestMux0Group1Reserved23 = 23|0x200U, /*!< Reserved23 */
    kDmaRequestMux0Group1Reserved24 = 24|0x200U, /*!< Reserved24 */
    kDmaRequestMux0Group1Reserved25 = 25|0x200U, /*!< Reserved25 */
    kDmaRequestMux0Group1Reserved26 = 26|0x200U, /*!< Reserved26 */
    kDmaRequestMux0Group1Reserved27 = 27|0x200U, /*!< Reserved27 */
    kDmaRequestMux0Group1Reserved28 = 28|0x200U, /*!< Reserved28 */
    kDmaRequestMux0Group1Reserved29 = 29|0x200U, /*!< Reserved29 */
    kDmaRequestMux0Group1Reserved30 = 30|0x200U, /*!< Reserved30 */
    kDmaRequestMux0Group1Reserved31 = 31|0x200U, /*!< Reserved31 */
    kDmaRequestMux0Group1FTM2Channel0 = 32|0x200U, /*!< FTM2 C0V. */
    kDmaRequestMux0Group1FTM2Channel1 = 33|0x200U, /*!< FTM2 C1V. */
    kDmaRequestMux0Group1SPI2Rx = 34|0x200U, /*!< SPI2 Receive. */
    kDmaRequestMux0Group1SPI2Tx = 35|0x200U, /*!< SPI2 Transmit. */
    kDmaRequestMux0Group1Reserved36 = 36|0x200U, /*!< Reserved36 */
    kDmaRequestMux0Group1Reserved37 = 37|0x200U, /*!< Reserved37 */
    kDmaRequestMux0Group1Reserved38 = 38|0x200U, /*!< Reserved38 */
    kDmaRequestMux0Group1Reserved39 = 39|0x200U, /*!< Reserved39 */
    kDmaRequestMux0Group1HSADC1A = 40|0x200U, /*!< HSADC1. */
    kDmaRequestMux0Group1HSADC1B = 41|0x200U, /*!< HSADC1. */
    kDmaRequestMux0Group1Reserved42 = 42|0x200U, /*!< Reserved42 */
    kDmaRequestMux0Group1Reserved43 = 43|0x200U, /*!< Reserved43 */
    kDmaRequestMux0Group1Reserved44 = 44|0x200U, /*!< Reserved44 */
    kDmaRequestMux0Group1ADC0 = 45|0x200U, /*!< ADC0. */
    kDmaRequestMux0Group1Reserved46 = 46|0x200U, /*!< Reserved46 */
    kDmaRequestMux0Group1Reserved47 = 47|0x200U, /*!< Reserved47 */
    kDmaRequestMux0Group1Reserved48 = 48|0x200U, /*!< Reserved48 */
    kDmaRequestMux0Group1Reserved49 = 49|0x200U, /*!< Reserved49 */
    kDmaRequestMux0Group1Reserved50 = 50|0x200U, /*!< Reserved50 */
    kDmaRequestMux0Group1Reserved51 = 51|0x200U, /*!< Reserved51 */
    kDmaRequestMux0Group1Reserved52 = 52|0x200U, /*!< Reserved52 */
    kDmaRequestMux0Group1Reserved53 = 53|0x200U, /*!< Reserved53 */
    kDmaRequestMux0Group1UART4Rx = 54|0x200U, /*!< UART4 Receive. */
    kDmaRequestMux0Group1UART4Tx = 55|0x200U, /*!< UART4 Transmit. */
    kDmaRequestMux0Group1UART5Rx = 56|0x200U, /*!< UART5 Receive. */
    kDmaRequestMux0Group1UART5Tx = 57|0x200U, /*!< UART5 Transmit. */
    kDmaRequestMux0Group1Reserved58 = 58|0x200U, /*!< Reserved58 */
    kDmaRequestMux0Group1Reserved59 = 59|0x200U, /*!< Reserved59 */
    kDmaRequestMux0Group1AlwaysOn60 = 60|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn61 = 61|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn62 = 62|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn63 = 63|0x200U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MKV58F1M0VLL22) || defined(CPU_MKV58F512VLL22) || defined(CPU_MKV58F1M0VLQ22) || defined(CPU_MKV58F512VLQ22) || \
    defined(CPU_MKV58F1M0VMD22) || defined(CPU_MKV58F512VMD22)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0PWM0WR0 = 6|0x100U, /*!< PWM0 Write Request 0. */
    kDmaRequestMux0PWM0WR1 = 7|0x100U, /*!< PWM0 Write Request 1. */
    kDmaRequestMux0PWM0WR2 = 8|0x100U, /*!< PWM0 Write Request 2. */
    kDmaRequestMux0PWM0WR3 = 9|0x100U, /*!< PWM0 Write Request 3. */
    kDmaRequestMux0PWM0CP0 = 10|0x100U, /*!< PWM0 Capture 0. */
    kDmaRequestMux0PWM0CP1 = 11|0x100U, /*!< PWM0 Capture 1. */
    kDmaRequestMux0PWM0CP2 = 12|0x100U, /*!< PWM0 Capture 2. */
    kDmaRequestMux0PWM0CP3 = 13|0x100U, /*!< PWM0 Capture 3. */
    kDmaRequestMux0CAN0 = 14|0x100U, /*!< CAN0. */
    kDmaRequestMux0CAN1 = 15|0x100U, /*!< CAN1. */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0Reserved18 = 18|0x100U, /*!< Reserved18 */
    kDmaRequestMux0Reserved19 = 19|0x100U, /*!< Reserved19 */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0. */
    kDmaRequestMux0Reserved23 = 23|0x100U, /*!< Reserved23 */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0CMP3 = 34|0x100U, /*!< CMP3. */
    kDmaRequestMux0Reserved35 = 35|0x100U, /*!< Reserved35 */
    kDmaRequestMux0FTM3Channel0 = 36|0x100U, /*!< FTM3 C0V. */
    kDmaRequestMux0FTM3Channel1 = 37|0x100U, /*!< FTM3 C1V. */
    kDmaRequestMux0FTM3Channel2 = 38|0x100U, /*!< FTM3 C2V. */
    kDmaRequestMux0FTM3Channel3 = 39|0x100U, /*!< FTM3 C3V. */
    kDmaRequestMux0HSADC0A = 40|0x100U, /*!< HSADC0. */
    kDmaRequestMux0HSADC0B = 41|0x100U, /*!< HSADC0. */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0CMP2 = 44|0x100U, /*!< CMP2. */
    kDmaRequestMux0DAC0 = 45|0x100U, /*!< DAC0. */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0PDB1 = 47|0x100U, /*!< PDB1. */
    kDmaRequestMux0PDB0 = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0FTM3Channel4 = 54|0x100U, /*!< FTM3 C4V. */
    kDmaRequestMux0FTM3Channel5 = 55|0x100U, /*!< FTM3 C5V. */
    kDmaRequestMux0FTM3Channel6 = 56|0x100U, /*!< FTM3 C6V. */
    kDmaRequestMux0FTM3Channel7 = 57|0x100U, /*!< FTM3 C7V. */
    kDmaRequestMux0Reserved58 = 58|0x100U, /*!< Reserved58 */
    kDmaRequestMux0Reserved59 = 59|0x100U, /*!< Reserved59 */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1Disable = 0|0x200U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Group1Reserved1 = 1|0x200U, /*!< Reserved1 */
    kDmaRequestMux0Group1UART2Rx = 2|0x200U, /*!< UART2 Receive. */
    kDmaRequestMux0Group1UART2Tx = 3|0x200U, /*!< UART2 Transmit. */
    kDmaRequestMux0Group1UART3Rx = 4|0x200U, /*!< UART3 Receive. */
    kDmaRequestMux0Group1UART3Tx = 5|0x200U, /*!< UART3 Transmit. */
    kDmaRequestMux0Group1PWM1WR0 = 6|0x200U, /*!< PWM1 Write Request 0. */
    kDmaRequestMux0Group1PWM1WR1 = 7|0x200U, /*!< PWM1 Write Request 1. */
    kDmaRequestMux0Group1PWM1WR2 = 8|0x200U, /*!< PWM1 Write Request 2. */
    kDmaRequestMux0Group1PWM1WR3 = 9|0x200U, /*!< PWM1 Write Request 3. */
    kDmaRequestMux0Group1PWM1CP0 = 10|0x200U, /*!< PWM1 Capture 0. */
    kDmaRequestMux0Group1PWM1CP1 = 11|0x200U, /*!< PWM1 Capture 1. */
    kDmaRequestMux0Group1PWM1CP2 = 12|0x200U, /*!< PWM1 Capture 2. */
    kDmaRequestMux0Group1PWM1CP3 = 13|0x200U, /*!< PWM1 Capture 3. */
    kDmaRequestMux0Group1CAN2 = 14|0x200U, /*!< CAN2. */
    kDmaRequestMux0Group1Reserved15 = 15|0x200U, /*!< Reserved15 */
    kDmaRequestMux0Group1SPI1Rx = 16|0x200U, /*!< SPI1 Receive. */
    kDmaRequestMux0Group1SPI1Tx = 17|0x200U, /*!< SPI1 Transmit. */
    kDmaRequestMux0Group1Reserved18 = 18|0x200U, /*!< Reserved18 */
    kDmaRequestMux0Group1Reserved19 = 19|0x200U, /*!< Reserved19 */
    kDmaRequestMux0Group1Reserved20 = 20|0x200U, /*!< Reserved20 */
    kDmaRequestMux0Group1Reserved21 = 21|0x200U, /*!< Reserved21 */
    kDmaRequestMux0Group1I2C1 = 22|0x200U, /*!< I2C1. */
    kDmaRequestMux0Group1Reserved23 = 23|0x200U, /*!< Reserved23 */
    kDmaRequestMux0Group1Reserved24 = 24|0x200U, /*!< Reserved24 */
    kDmaRequestMux0Group1Reserved25 = 25|0x200U, /*!< Reserved25 */
    kDmaRequestMux0Group1Reserved26 = 26|0x200U, /*!< Reserved26 */
    kDmaRequestMux0Group1Reserved27 = 27|0x200U, /*!< Reserved27 */
    kDmaRequestMux0Group1Reserved28 = 28|0x200U, /*!< Reserved28 */
    kDmaRequestMux0Group1Reserved29 = 29|0x200U, /*!< Reserved29 */
    kDmaRequestMux0Group1Reserved30 = 30|0x200U, /*!< Reserved30 */
    kDmaRequestMux0Group1Reserved31 = 31|0x200U, /*!< Reserved31 */
    kDmaRequestMux0Group1FTM2Channel0 = 32|0x200U, /*!< FTM2 C0V. */
    kDmaRequestMux0Group1FTM2Channel1 = 33|0x200U, /*!< FTM2 C1V. */
    kDmaRequestMux0Group1SPI2Rx = 34|0x200U, /*!< SPI2 Receive. */
    kDmaRequestMux0Group1SPI2Tx = 35|0x200U, /*!< SPI2 Transmit. */
    kDmaRequestMux0Group1IEEE1588Timer0 = 36|0x200U, /*!< ENET IEEE 1588 timer 0. */
    kDmaRequestMux0Group1IEEE1588Timer1 = 37|0x200U, /*!< ENET IEEE 1588 timer 1. */
    kDmaRequestMux0Group1IEEE1588Timer2 = 38|0x200U, /*!< ENET IEEE 1588 timer 2. */
    kDmaRequestMux0Group1IEEE1588Timer3 = 39|0x200U, /*!< ENET IEEE 1588 timer 3. */
    kDmaRequestMux0Group1HSADC1A = 40|0x200U, /*!< HSADC1. */
    kDmaRequestMux0Group1HSADC1B = 41|0x200U, /*!< HSADC1. */
    kDmaRequestMux0Group1Reserved42 = 42|0x200U, /*!< Reserved42 */
    kDmaRequestMux0Group1Reserved43 = 43|0x200U, /*!< Reserved43 */
    kDmaRequestMux0Group1Reserved44 = 44|0x200U, /*!< Reserved44 */
    kDmaRequestMux0Group1ADC0 = 45|0x200U, /*!< ADC0. */
    kDmaRequestMux0Group1Reserved46 = 46|0x200U, /*!< Reserved46 */
    kDmaRequestMux0Group1Reserved47 = 47|0x200U, /*!< Reserved47 */
    kDmaRequestMux0Group1Reserved48 = 48|0x200U, /*!< Reserved48 */
    kDmaRequestMux0Group1Reserved49 = 49|0x200U, /*!< Reserved49 */
    kDmaRequestMux0Group1Reserved50 = 50|0x200U, /*!< Reserved50 */
    kDmaRequestMux0Group1Reserved51 = 51|0x200U, /*!< Reserved51 */
    kDmaRequestMux0Group1Reserved52 = 52|0x200U, /*!< Reserved52 */
    kDmaRequestMux0Group1Reserved53 = 53|0x200U, /*!< Reserved53 */
    kDmaRequestMux0Group1UART4Rx = 54|0x200U, /*!< UART4 Receive. */
    kDmaRequestMux0Group1UART4Tx = 55|0x200U, /*!< UART4 Transmit. */
    kDmaRequestMux0Group1UART5Rx = 56|0x200U, /*!< UART5 Receive. */
    kDmaRequestMux0Group1UART5Tx = 57|0x200U, /*!< UART5 Transmit. */
    kDmaRequestMux0Group1Reserved58 = 58|0x200U, /*!< Reserved58 */
    kDmaRequestMux0Group1Reserved59 = 59|0x200U, /*!< Reserved59 */
    kDmaRequestMux0Group1AlwaysOn60 = 60|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn61 = 61|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn62 = 62|0x200U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0Group1AlwaysOn63 = 63|0x200U, /*!< DMAMUX Always Enabled slot. */
#elif defined(CPU_MKW21D256VHA5) || defined(CPU_MKW21D512VHA5) || defined(CPU_MKW22D512VHA5) || defined(CPU_MKW24D512VHA5)
    kDmaRequestMux0Disable = 0|0x100U, /*!< DMAMUX TriggerDisabled. */
    kDmaRequestMux0Reserved1 = 1|0x100U, /*!< Reserved1 */
    kDmaRequestMux0UART0Rx = 2|0x100U, /*!< UART0 Receive. */
    kDmaRequestMux0UART0Tx = 3|0x100U, /*!< UART0 Transmit. */
    kDmaRequestMux0UART1Rx = 4|0x100U, /*!< UART1 Receive. */
    kDmaRequestMux0UART1Tx = 5|0x100U, /*!< UART1 Transmit. */
    kDmaRequestMux0UART2Rx = 6|0x100U, /*!< UART2 Receive. */
    kDmaRequestMux0UART2Tx = 7|0x100U, /*!< UART2 Transmit. */
    kDmaRequestMux0Reserved8 = 8|0x100U, /*!< Reserved8 */
    kDmaRequestMux0Reserved9 = 9|0x100U, /*!< Reserved9 */
    kDmaRequestMux0Reserved10 = 10|0x100U, /*!< Reserved10 */
    kDmaRequestMux0Reserved11 = 11|0x100U, /*!< Reserved11 */
    kDmaRequestMux0Reserved12 = 12|0x100U, /*!< Reserved12 */
    kDmaRequestMux0Reserved13 = 13|0x100U, /*!< Reserved13 */
    kDmaRequestMux0I2S0Rx = 14|0x100U, /*!< I2S0 Receive. */
    kDmaRequestMux0I2S0Tx = 15|0x100U, /*!< I2S0 Transmit. */
    kDmaRequestMux0SPI0Rx = 16|0x100U, /*!< SPI0 Receive. */
    kDmaRequestMux0SPI0Tx = 17|0x100U, /*!< SPI0 Transmit. */
    kDmaRequestMux0SPI1Rx = 18|0x100U, /*!< SPI1 Receive. */
    kDmaRequestMux0SPI1Tx = 19|0x100U, /*!< SPI1 Transmit. */
    kDmaRequestMux0Reserved20 = 20|0x100U, /*!< Reserved20 */
    kDmaRequestMux0Reserved21 = 21|0x100U, /*!< Reserved21 */
    kDmaRequestMux0I2C0 = 22|0x100U, /*!< I2C0. */
    kDmaRequestMux0I2C1 = 23|0x100U, /*!< I2C1. */
    kDmaRequestMux0FTM0Channel0 = 24|0x100U, /*!< FTM0 C0V. */
    kDmaRequestMux0FTM0Channel1 = 25|0x100U, /*!< FTM0 C1V. */
    kDmaRequestMux0FTM0Channel2 = 26|0x100U, /*!< FTM0 C2V. */
    kDmaRequestMux0FTM0Channel3 = 27|0x100U, /*!< FTM0 C3V. */
    kDmaRequestMux0FTM0Channel4 = 28|0x100U, /*!< FTM0 C4V. */
    kDmaRequestMux0FTM0Channel5 = 29|0x100U, /*!< FTM0 C5V. */
    kDmaRequestMux0FTM0Channel6 = 30|0x100U, /*!< FTM0 C6V. */
    kDmaRequestMux0FTM0Channel7 = 31|0x100U, /*!< FTM0 C7V. */
    kDmaRequestMux0FTM1Channel0 = 32|0x100U, /*!< FTM1 C0V. */
    kDmaRequestMux0FTM1Channel1 = 33|0x100U, /*!< FTM1 C1V. */
    kDmaRequestMux0FTM2Channel0 = 34|0x100U, /*!< FTM2 C0V. */
    kDmaRequestMux0FTM2Channel1 = 35|0x100U, /*!< FTM2 C1V. */
    kDmaRequestMux0Reserved36 = 36|0x100U, /*!< Reserved36 */
    kDmaRequestMux0Reserved37 = 37|0x100U, /*!< Reserved37 */
    kDmaRequestMux0Reserved38 = 38|0x100U, /*!< Reserved38 */
    kDmaRequestMux0Reserved39 = 39|0x100U, /*!< Reserved39 */
    kDmaRequestMux0ADC0 = 40|0x100U, /*!< ADC0. */
    kDmaRequestMux0Reserved41 = 41|0x100U, /*!< Reserved41 */
    kDmaRequestMux0CMP0 = 42|0x100U, /*!< CMP0. */
    kDmaRequestMux0CMP1 = 43|0x100U, /*!< CMP1. */
    kDmaRequestMux0Reserved44 = 44|0x100U, /*!< Reserved44 */
    kDmaRequestMux0Reserved45 = 45|0x100U, /*!< Reserved45 */
    kDmaRequestMux0Reserved46 = 46|0x100U, /*!< Reserved46 */
    kDmaRequestMux0CMT = 47|0x100U, /*!< CMT. */
    kDmaRequestMux0PDB = 48|0x100U, /*!< PDB0. */
    kDmaRequestMux0PortA = 49|0x100U, /*!< PTA. */
    kDmaRequestMux0PortB = 50|0x100U, /*!< PTB. */
    kDmaRequestMux0PortC = 51|0x100U, /*!< PTC. */
    kDmaRequestMux0PortD = 52|0x100U, /*!< PTD. */
    kDmaRequestMux0PortE = 53|0x100U, /*!< PTE. */
    kDmaRequestMux0AlwaysOn54 = 54|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn55 = 55|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn56 = 56|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn57 = 57|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn58 = 58|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn59 = 59|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn60 = 60|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn61 = 61|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn62 = 62|0x100U, /*!< DMAMUX Always Enabled slot. */
    kDmaRequestMux0AlwaysOn63 = 63|0x100U, /*!< DMAMUX Always Enabled slot. */
#elif defined(MCU_MKL28T7) // manually added
    kDmaRequestMux0Disable = 0|0x300U,
    kDmaRequestMux0FLEXIOShifter0 = 1|0x300U,
    kDmaRequestMux0FLEXIOShifter1 = 2|0x300U,
    kDmaRequestMux0FLEXIOShifter2 = 3|0x300U,
    kDmaRequestMux0FLEXIOShifter3 = 4|0x300U,
    kDmaRequestMux0FLEXIOShifter4 = 5|0x300U,
    kDmaRequestMux0FLEXIOShifter5 = 6|0x300U,
    kDmaRequestMux0FLEXIOShifter6 = 7|0x300U,
    kDmaRequestMux0FLEXIOShifter7 = 8|0x300U,
    kDmaRequestMux0LPI2C0Rx = 9|0x300U,
    kDmaRequestMux0LPI2C0Tx = 10|0x300U,
    kDmaRequestMux0LPI2C1Rx = 11|0x300U,
    kDmaRequestMux0LPI2C1Tx = 12|0x300U,
    kDmaRequestMux0LPI2C2Rx = 13|0x300U,
    kDmaRequestMux0LPI2C2Tx = 14|0x300U,
    kDmaRequestMux0LPUART0Rx = 15|0x300U,
    kDmaRequestMux0LPUART0Tx = 16|0x300U,
    kDmaRequestMux0LPUART1Rx = 17|0x300U,
    kDmaRequestMux0LPUART1Tx = 18|0x300U,
    kDmaRequestMux0LPUART2Rx = 19|0x300U,
    kDmaRequestMux0LPUART2Tx = 20|0x300U,
    kDmaRequestMux0LPSPI0Rx = 21|0x300U,
    kDmaRequestMux0LPSPI0Tx = 22|0x300U,
    kDmaRequestMux0LPSPI1Rx = 23|0x300U,
    kDmaRequestMux0LPSPI1Tx = 24|0x300U,
    kDmaRequestMux0LPSPI2Rx = 25|0x300U,
    kDmaRequestMux0LPSPI2Tx = 26|0x300U,
    kDmaRequestMux0TPM0Channel0 = 27|0x300U,
    kDmaRequestMux0TPM0Channel1 = 28|0x300U,
    kDmaRequestMux0TPM0Channel2 = 29|0x300U,
    kDmaRequestMux0TPM0Channel3 = 30|0x300U,
    kDmaRequestMux0TPM0Channel4 = 31|0x300U,
    kDmaRequestMux0TPM0Channel5 = 32|0x300U,
    kDmaRequestMux0Reserved33 = 33|0x300U,
    kDmaRequestMux0Reserved34 = 34|0x300U,
    kDmaRequestMux0TPM0Overflow = 35|0x300U,
    kDmaRequestMux0TPM1Channel0 = 36|0x300U,
    kDmaRequestMux0TPM1Channel1 = 37|0x300U,
    kDmaRequestMux0TPM1Overflow = 38|0x300U,
    kDmaRequestMux0TPM2Channel0 = 39|0x300U,
    kDmaRequestMux0TPM2Channel1 = 40|0x300U,
    kDmaRequestMux0TPM2Overflow = 41|0x300U,
    kDmaRequestMux0PORTRPM = 42|0x300U,
    kDmaRequestMux0EMVSIMRx = 43|0x300U,
    kDmaRequestMux0EMVSIMTx = 44|0x300U,
    kDmaRequestMux0I2S0Rx = 45|0x300U,
    kDmaRequestMux0I2S0Tx = 46|0x300U,
    kDmaRequestMux0PORTA = 47|0x300U,
    kDmaRequestMux0PORTB = 48|0x300U,
    kDmaRequestMux0PortC = 49|0x300U,
    kDmaRequestMux0PortD = 50|0x300U,
    kDmaRequestMux0PortE = 51|0x300U,
    kDmaRequestMux0ADC0 = 52|0x300U,
    kDmaRequestMux0Reserved53 = 53|0x300U,
    kDmaRequestMux0DAC0 = 54|0x300U,
    kDmaRequestMux0Reserved55 = 55|0x300U,
    kDmaRequestMux0CMP0 = 56|0x300U,
    kDmaRequestMux0CMP1 = 57|0x300U,
    kDmaRequestMux0Reserved58 = 58|0x300U,
    kDmaRequestMux0Reserved59 = 59|0x300U,
    kDmaRequestMux0AlwaysOn60 = 60|0x300U,
    kDmaRequestMux0AlwaysOn61 = 61|0x300U,
    kDmaRequestMux0AlwaysOn62 = 62|0x300U,
    kDmaRequestMux0AlwaysOn63 = 63|0x300U,    
#else
    #error "No valid CPU defined!"
#endif
} dma_request_source_t;

/* @} */

#endif /* __FSL_EDMA_REQUEST_H__ */

/*******************************************************************************
 * EOF
 ******************************************************************************/

